@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: ThankRedirect.py 9868 2017-04-16 09:05:26Z Lavender $
+# $Id: ThankRedirect.py 9895 2017-04-23 04:33:47Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,32 +12,47 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-16 17:05:26 +0800 (週日, 16 四月 2017) $
-# $Revision: 9868 $
+# $Date: 2017-04-23 12:33:47 +0800 (週日, 23 四月 2017) $
+# $Revision: 9895 $
 
 from django import template
 from django.utils.safestring import mark_safe
 from django.conf import settings
+from django.template.loader import get_template
+from django.template import Context
+
+from Zephyrus.landing import getErrorMessage
 
 register = template.Library()
 
 @register.simple_tag
 def ThankRedirect(request):
-    fromUrl = request.GET.get('fromurl')
+    fromUrl = request.GET.get('from_url')
+    errorCode = int(request.GET.get('error'))
     if fromUrl == None:
         return ''
     
-    try:
+    if hasattr(settings, 'ZEPHYRUS_LANDING_THANK_WAIT_TIME'):
         time = settings.ZEPHYRUS_LANDING_THANK_WAIT_TIME
-    except Exception as e:
+    else:
         time = 3000
+
+    errorHtml = get_template('landing/ErrorMessage.html')
+    errorMessage = getErrorMessage(errorCode)
+    print errorMessage
+    errorHtml = errorHtml.render(
+            Context({'errorMessage': errorMessage,})
+        )
+    print errorHtml
+    
     return mark_safe(
         '''
+        %s
         <script>
             var redirect = function(){
                 setTimeout(function(){window.location.replace('%s');}, %d);
             };
             redirect();
         </script>
-        ''' % (fromUrl, time)
+        ''' % (errorHtml, fromUrl, time)
     )
