@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 9868 2017-04-16 09:05:26Z Lavender $
+# $Id: views.py 9913 2017-04-24 13:07:32Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,12 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-16 17:05:26 +0800 (週日, 16 四月 2017) $
-# $Revision: 9868 $
+# $Date: 2017-04-24 21:07:32 +0800 (週一, 24 四月 2017) $
+# $Revision: 9913 $
 
 import datetime
 import logging
-import re
+import urllib
 
 from django.shortcuts import redirect
 from django.contrib import messages
@@ -27,23 +27,21 @@ from django.conf import settings
 from django.template.loader import get_template
 from django.template import Context
 from django.contrib import auth
+from django.core.validators import validate_email
+from django.core.exceptions import ValidationError
 
-from models import Email
+from Zephyrus.landing import ErrorCode
+from Zephyrus.landing.models import Email
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 logger.addHandler(logging.StreamHandler())
 
-#ERROR_CODES
-NORMAL = 0
-SAVE_ERROR = 1
-SEND_ERROR = 2
-EMAIL_FORMAT_ERROR = 3
-
 def sendAndRedirect(request, email, fromUrl, redirectTo):
-        errorCode = NORMAL
-        
-        if re.match(r'(\w+@[a-zA-Z_]+?\.[a-zA-Z]{2,6})', email):
+        errorCode = ErrorCode.NORMAL
+          
+        try:
+            validate_email(email)
             try:
                 email = Email.objects.create(
                     email=email,
@@ -51,7 +49,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo):
                 )
                 email.save()
             except Exception as e:
-                errorCode = SAVE_ERROR
+                errorCode = ErrorCode.SAVE_EMAIL
                 logger.error('Not successfully save email: %s' % str(e))
 
             try:
@@ -59,6 +57,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo):
                     "Customer id : %d\nCustomer email : %s\n" % 
                     (email.id, email.email))
                 message += "Date : %s" % datetime.datetime.now()
+                message += "From : %s" % fromUrl
                 
                 title = (
                     '[Landing %s] - customer use landing page' % 
@@ -72,12 +71,12 @@ def sendAndRedirect(request, email, fromUrl, redirectTo):
                     fail_silently=False
                 )
                 
-                mail = get_template('landing/CustomerMail.txt')
+                mail = get_template('landing/ThankEmail.txt')
                 replaceStr = Context({
                     'email': email.email,
                 })
                 
-                title = get_template('landing/CustomerMailSubject.txt')
+                title = get_template('landing/ThankEmailSubject.txt')
                 
                 send_mail(
                     title.render(),
@@ -87,17 +86,21 @@ def sendAndRedirect(request, email, fromUrl, redirectTo):
                     fail_silently=False
                 )
             except Exception as e:
-                errorCode = SEND_ERROR
+                errorCode = ErrorCode.SEND_EMAIL
                 logger.error('Not successfully send email: %s' % str(e))
-        else:
-            errorCode = EMAIL_FORMAT_ERROR
+        except ValidationError as e:
+            errorCode = ErrorCode.EMAIL_FORMAT 
+            logger.error('Email format error: %s' % str(e))
         
         if redirectTo:        
-            url = redirectTo
+            url = urllib.quote(redirectTo)
         else:
-            url = fromUrl + settings.ZEPHYRUS_LANDING_THANK_PATH
+            if hasattr(settings, "ZEPHYRUS_LANDING_THANK_URL"):
+                url = fromUrl + settings.ZEPHYRUS_LANDING_THANK_URL
+            else:
+                url = fromUrl + "thank"
             
-        url = url + "?fromurl=%s&errorcode=%d" % (fromUrl, errorCode)
+        url = url + "?from_url=%s&error=%d" % (fromUrl, errorCode)
 
         return redirect(url)
     
